##  Validation
After configuring all four automations, validate the implementation using the following test scenarios:
  1. Add a subscription to an application.
  2. Remove a subscription from an application.
  3. Create a relation from an application to an IT component.
  4. Remove a relation from an application to an IT component.


YesNo
Send
